/*
* Copyright (c) 2020 - 2022 Xilinx, Inc.  All rights reserved.
* Copyright (c) 2022 - 2023 Advanced Micro Devices, Inc.  All rights reserved.
*
* SPDX-License-Identifier: MIT
*/
var app_strings = {
	"tab_title":"VCK190 Evaluation Kit",
	"app_title":"System Controller Landing Page",
	"xilinx_icon":"",
	"home_tab":{
		"title":"Welcome & Get Started with Versal AI Core Series VCK190 Evaluation Kit",
		"left_pane":[
			{
				"image":"",
				"text":"",
				"button_title":"",
				"button_link":"",
			},
			{
				"image":"",
				"text":"",
				"button_title":"",
				"button_link":"",
			}
		],
		"center_pane":{
			"image":"",
			"text":"",
			"button_title":"",
			"button_link":"",
		},
	},
	"test_board":{
		"center_pane":{
			"image":"",
			"text":"",
			"button_title":"",
			"button_link":"",
		},
		
	},
	"run_demos":{

	},
	"develop_tools":{

	},
};
